local addonName, addon = ...
if not addon.healthCheck then return end

local frame = addon.frame
frame.name = addonName
frame:Hide()

frame:SetScript("OnShow", function(frame)

    local function newCheckbox(label, description, onClick)
        local check = CreateFrame("CheckButton", "CDSpy" .. label, frame, "InterfaceOptionsCheckButtonTemplate")
        check:SetScript("OnClick", function(self)
            PlaySound(self:GetChecked() and "igMainMenuOptionCheckBoxOn" or "igMainMenuOptionCheckBoxOff")
            onClick(self, self:GetChecked() and true or false)
        end)
        check.label = _G[check:GetName() .. "Text"]
        check.label:SetText(label)
        check.tooltipText = label
        check.tooltipRequirement = description
        return check
    end
  
  local function CheckEditBoxRaid(self)
    local msg = self:GetText()
    CDSpyDB.raid_channel_name = msg
    CDSpyDB.raid_channel_id = GetChannelName(msg)
  --  options.update()
  end
  
  local function CheckEditBoxParty(self)
    local msg = self:GetText()
    CDSpyDB.party_channel_name = msg
    CDSpyDB.party_channel_id = GetChannelName(msg)
   -- options.update()
  end
  
  local function CheckEditBoxPug(self)
    local msg = self:GetText()
    CDSpyDB.pug_channel_name = msg
    CDSpyDB.pug_channel_id = GetChannelName(msg)
   -- options.update()
  end

  -- fancy "CDSpy" in the top left
  local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
    title:SetPoint("TOPLEFT", 16, -16)
    title:SetText(addonName)
  
  -- authors info
  local author_label = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
    author_label:SetPoint("TOPLEFT", title, 0, -32)
    author_label:SetText("Authors:")
  
  local author_info = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
    author_info:SetPoint("TOPLEFT",author_label,"TOPRIGHT",4,0)
    author_info:SetText("Madsushi and Perfect, Mal'Ganis-US")

  -- emaiil info
  local email_label = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
    email_label:SetPoint("TOPLEFT", author_label, 0, -16)
    email_label:SetText("Email:")
  
  local email_info = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
    email_info:SetPoint("TOPLEFT",email_label,"TOPRIGHT",4,0)
    email_info:SetText("madsushi@gmail.com")
    
    
  -- General Options header
  local general_options = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
    general_options:SetPoint("TOPLEFT", email_label, 0, -32)
    general_options:SetText("General Options")
    
  local enable_box = newCheckbox(
      "Global Announce",
      "If unchecked, NO announcements will go out.",
      function(self, value) CDSpyDB.enable_toggle = value end)
    enable_box:SetChecked(CDSpyDB.enable_toggle)
    enable_box:SetPoint("TOPLEFT", general_options, "BOTTOMLEFT", 0, -8)      
    
  local party_raid_toggle_box = newCheckbox(
      "Party/Raid Announce",
      "Mythics, Raids, Player-Generated Groups. Things you don't have to queue for.",
      function(self, value) CDSpyDB.party_raid_toggle = value end)
    party_raid_toggle_box:SetChecked(CDSpyDB.party_raid_toggle)
    party_raid_toggle_box:SetPoint("TOPLEFT", enable_box, "TOPRIGHT", 150, 0)   
    
  local pug_toggle_box = newCheckbox(
      "Queued Instance Announce",
      "LFR, LFD, Battlegrounds, and Scenarios. Things you have to queue for.",
      function(self, value) CDSpyDB.pug_toggle = value end)
    pug_toggle_box:SetChecked(CDSpyDB.pug_toggle)
    pug_toggle_box:SetPoint("TOPLEFT", party_raid_toggle_box, "TOPRIGHT", 150, 0)  

    
  -- Chat Options header
  local chat_options = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
    chat_options:SetPoint("TOPLEFT", general_options, 0, -70)
    chat_options:SetText("Chat Output Options")  
  
  local info = {}
  
  local party_header = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
    party_header:SetPoint("TOPLEFT", chat_options, 10, -30)
    party_header:SetText("Party Output Settings") 
    
  local raid_header = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
    raid_header:SetPoint("TOPLEFT", party_header, 190, 0)
    raid_header:SetText("Raid Output Settings") 
    
  local pug_header = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
    pug_header:SetPoint("TOPLEFT", raid_header, 190, 0)
    pug_header:SetText("Queued Output Settings")     

  local partyChannelDropdown = CreateFrame("Frame", "CDSpyPartyChannel", frame, "UIDropDownMenuTemplate")
  partyChannelDropdown:SetPoint("TOPLEFT", chat_options, "TOPLEFT", 0, -50)
  partyChannelDropdown.initialize = function()
    wipe(info)
    local channels = {"RAID", "PARTY", "INSTANCE_CHAT", "GUILD", "SAY", "CHANNEL"}
    local names = {"RAID", "PARTY", "INSTANCE", "GUILD", "SAY", "CHANNEL"}
    for i, channel in next, channels do
      info.text = names[i]
      info.value = channel
      info.func = function(self)
        CDSpyDB.party_output = self.value
        CDSpyPartyChannelText:SetText(self:GetText())
      end
      info.checked = channel == CDSpyDB.party_output
      UIDropDownMenu_AddButton(info)
    end
  end
  CDSpyPartyChannelText:SetText("Party Output")
  
  
  local party_channel_label = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
    party_channel_label:SetPoint("TOPLEFT", partyChannelDropdown, 10, -35)
    party_channel_label:SetText("Party - Custom Channel")
  
  
  local party_channel_id_box = CreateFrame("EditBox", "CDSpyPartyChannelID", frame, "InputBoxTemplate")
  
  function party_channel_id_box:OnEditFocusGained()
    self.value = self:GetValue()
  end

  function party_channel_id_box:OnEnterPressed()
    local value = self:GetValue()
    self:CDSpy('OnTextChanged', value)
    self:CDSpy('OnInput', value)
    self:CDSpy('OnUpdate')
    self:ClearFocus()
  end

  function party_channel_id_box:OnEscapePressed()
    self:SetValue(self.value or '')
    self:ClearFocus()
  end
  
  
    party_channel_id_box:SetPoint("TOPLEFT", partyChannelDropdown, "BOTTOMLEFT", 25, -20)
  party_channel_id_box:SetSize(125, 20)
  party_channel_id_box:SetAutoFocus(false)
    party_channel_id_box:SetScript("OnShow", frame.update)
    party_channel_id_box:SetScript("OnEnterPressed", CheckEditBoxParty)
  party_channel_id_box:SetScript("OnEditFocusLost", CheckEditBoxParty)
  party_channel_id_box:SetScript("OnTextChanged", CheckEditBoxParty)  
  party_channel_id_box:SetText(CDSpyDB.party_channel_id)
    
  
  
  local raidChannelDropdown = CreateFrame("Frame", "CDSpyRaidChannel", frame, "UIDropDownMenuTemplate")
  raidChannelDropdown:SetPoint("LEFT", partyChannelDropdown, "RIGHT", 150, 0)
  raidChannelDropdown.initialize = function()
    wipe(info)
    local channels = {"RAID", "PARTY", "INSTANCE_CHAT", "GUILD", "SAY", "CHANNEL"}
    local names = {"RAID", "PARTY", "INSTANCE", "GUILD", "SAY", "CHANNEL"}
    for i, channel in next, channels do
      info.text = names[i]
      info.value = channel
      info.func = function(self)
        CDSpyDB.raid_output = self.value
        CDSpyRaidChannelText:SetText(self:GetText())
      end
      info.checked = channel == CDSpyDB.raid_output
      UIDropDownMenu_AddButton(info)
    end
  end
  CDSpyRaidChannelText:SetText("Raid Output")
  
  
  
  local raid_channel_label = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
    raid_channel_label:SetPoint("TOPLEFT", raidChannelDropdown, 10, -35)
    raid_channel_label:SetText("Raid - Custom Channel")
  
  
  
  local raid_channel_id_box = CreateFrame("EditBox", "CDSpyRaidChannelID", frame, "InputBoxTemplate")
  
  function raid_channel_id_box:OnEditFocusGained()
    self.value = self:GetValue()
  end

  function raid_channel_id_box:OnEnterPressed()
    local value = self:GetValue()
    self:CDSpy('OnTextChanged', value)
    self:CDSpy('OnInput', value)
    self:CDSpy('OnUpdate')
    self:ClearFocus()
  end

  function raid_channel_id_box:OnEscapePressed()
    self:SetValue(self.value or '')
    self:ClearFocus()
  end
  
  
    raid_channel_id_box:SetPoint("TOPLEFT", raidChannelDropdown, "BOTTOMLEFT", 25, -20)
  raid_channel_id_box:SetSize(125, 20)
  raid_channel_id_box:SetAutoFocus(false)
    raid_channel_id_box:SetScript("OnShow", frame.update)
    raid_channel_id_box:SetScript("OnEnterPressed", CheckEditBoxRaid)
  raid_channel_id_box:SetScript("OnEditFocusLost", CheckEditBoxRaid)
  raid_channel_id_box:SetScript("OnTextChanged", CheckEditBoxRaid)
  raid_channel_id_box:SetText(CDSpyDB.raid_channel_name)
  

  
  local pugChannelDropdown = CreateFrame("Frame", "CDSpyPugChannel", frame, "UIDropDownMenuTemplate")
  pugChannelDropdown:SetPoint("LEFT", raidChannelDropdown, "RIGHT", 150, 0)
  pugChannelDropdown.initialize = function()
    wipe(info)
    local channels = {"RAID", "PARTY", "INSTANCE_CHAT", "GUILD", "SAY", "CHANNEL"}
    local names = {"RAID", "PARTY", "INSTANCE", "GUILD", "SAY", "CHANNEL"}
    for i, channel in next, channels do
      info.text = names[i]
      info.value = channel
      info.func = function(self)
        CDSpyDB.pug_output = self.value
        CDSpyPugChannelText:SetText(self:GetText())
      end
      info.checked = channel == CDSpyDB.pug_output
      UIDropDownMenu_AddButton(info)
    end
  end
  CDSpyPugChannelText:SetText("PUG Output")
  
  
  local pug_channel_label = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
    pug_channel_label:SetPoint("TOPLEFT", pugChannelDropdown, 10, -35)
    pug_channel_label:SetText("Queued - Custom Channel")
  
  
  local pug_channel_id_box = CreateFrame("EditBox", "CDSpyPugChannelID", frame, "InputBoxTemplate")
  
  function pug_channel_id_box:OnEditFocusGained()
    self.value = self:GetValue()
  end

  function pug_channel_id_box:OnEnterPressed()
    local value = self:GetValue()
    self:CDSpy('OnTextChanged', value)
    self:CDSpy('OnInput', value)
    self:CDSpy('OnUpdate')
    self:ClearFocus()
  end

  function pug_channel_id_box:OnEscapePressed()
    self:SetValue(self.value or '')
    self:ClearFocus()
  end
  
  
    pug_channel_id_box:SetPoint("TOPLEFT", pugChannelDropdown, "BOTTOMLEFT", 25, -20)
  pug_channel_id_box:SetSize(125, 20)
  pug_channel_id_box:SetAutoFocus(false)
    pug_channel_id_box:SetScript("OnShow", frame.update)
    pug_channel_id_box:SetScript("OnEnterPressed", CheckEditBoxPug)
  pug_channel_id_box:SetScript("OnEditFocusLost", CheckEditBoxPug)
  pug_channel_id_box:SetScript("OnTextChanged", CheckEditBoxPug)
  pug_channel_id_box:SetText(CDSpyDB.pug_channel_id)
    frame:SetScript("OnShow", nil)
    
    
  -- Criteria Options header
  local criteria_options = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
    criteria_options:SetPoint("TOPLEFT", chat_options, 0, -140)
    criteria_options:SetText("Criteria Options")  
    
  local taunt_toggle_box = newCheckbox(
      "Announce Taunts",
      "Includes pet taunts.",
       function(self, value) CDSpyDB.taunt_toggle = value end)
  taunt_toggle_box:SetChecked(CDSpyDB.taunt_toggle)
  taunt_toggle_box:SetPoint("TOPLEFT", criteria_options, "BOTTOMLEFT", -2, -8)
    
  local tank_toggle_box = newCheckbox(
      "Announce Tank Cooldowns",
      "These are CDs used by tanks themselves.",
       function(self, value) CDSpyDB.tank_toggle = value end)
  tank_toggle_box:SetChecked(CDSpyDB.tank_toggle)
  tank_toggle_box:SetPoint("TOPLEFT", taunt_toggle_box, "TOPRIGHT", 160, 0)    
    
  local healer_toggle_box = newCheckbox(
      "Announce Healer Cooldowns",
      "These are CDs used by healers, including CDs they cast on tanks.",
       function(self, value) CDSpyDB.healer_toggle = value end)
  healer_toggle_box:SetChecked(CDSpyDB.healer_toggle)
  healer_toggle_box:SetPoint("TOPLEFT", taunt_toggle_box, "BOTTOMLEFT", 0, -8)
    
  -- Advanced Options header
  local advanced_options = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
    advanced_options:SetPoint("TOPLEFT", criteria_options, 0, -100)
    advanced_options:SetText("Advanced Options") 
    
  local override_box = newCheckbox(
        "Override Mode (requires reload)",
        "Override Mode causes CDSpy to ignore whether or not you're in combat, whether or not you're in an instance, and whether or not you have any Chat Option toggles set. Best used for testing the addon outside of instances.",
        function(self, value)
      CDSpyDB.override = value
      ReloadUI()
    end)
    override_box:SetChecked(CDSpyDB.override)
    override_box:SetPoint("TOPLEFT", advanced_options, "BOTTOMLEFT", -2, -8)
  
  local debug_box = newCheckbox(
        "Debug Mode",
        "Outputs events to your local console, in addition to any other channels configured. Best used by disabling Global Announce so that only you see events.",
        function(self, value) CDSpyDB.debug_toggle = value end)
    debug_box:SetChecked(CDSpyDB.debug_toggle)
    debug_box:SetPoint("TOPLEFT", override_box, "TOPRIGHT", 160, 0) 
  


    
    
end)

InterfaceOptions_AddCategory(frame)

